==> revive-adserver-5.3.1.zip: revive-adserver-5.3.1/lib/max/language/ca/installer.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

/** status messages * */

/** welcome step * */

/** check step * */


$GLOBALS['strError'] = "Error";
$GLOBALS['strWarning'] = "Advertència";
$GLOBALS['strOK'] = "D'acord";
$GLOBALS['strSyscheckStatus'] = "Estat";
$GLOBALS['strCheckError'] = 'error';
$GLOBALS['strCheckErrors'] = 'errors';
$GLOBALS['strCheckWarning'] = 'advertència';
$GLOBALS['strCheckWarnings'] = 'advertències';

/** admin login step * */
$GLOBALS['strLoginProgressMessage'] = 'Iniciant sessió...';

/** database step * */
$GLOBALS['strDbProgressMessageInstall'] = 'S\'està instal·lant la base de dades...';
$GLOBALS['strDbProgressMessageUpgrade'] = 'S\'està actualitzant la base de dades...';
$GLOBALS['strDBInstallSuccess'] = "La base de dades s'ha creat amb èxit";
$GLOBALS['strDBUpgradeSuccess'] = "La base de dades s'ha actualitzat amb èxit";


/** config step * */
$GLOBALS['strConfigureUpgradeTitle'] = "Preferències de configuració";
$GLOBALS['strPreviousInstallTitle'] = "Instal·lació anterior";

/** jobs step * */


/** finish step * */

==> revive-adserver-5.4.1.zip: revive-adserver-5.4.1/lib/max/language/ca/installer.lang.php <==
<?php

/*
  +---------------------------------------------------------------------------+
  | Revive Adserver                                                           |
  | http://www.revive-adserver.com                                            |
  |                                                                           |
  | Copyright: See the COPYRIGHT.txt file.                                    |
  | License: GPLv2 or later, see the LICENSE.txt file.                        |
  +---------------------------------------------------------------------------+
 */

/** status messages * */

/** welcome step * */

/** check step * */


$GLOBALS['strError'] = "Error";
$GLOBALS['strWarning'] = "Advertència";
$GLOBALS['strOK'] = "D'acord";
$GLOBALS['strSyscheckValue'] = "Valor actual";
$GLOBALS['strSyscheckStatus'] = "Estat";
$GLOBALS['strBrowserCookies'] = 'Cookies de navegador';
$GLOBALS['strPHPConfiguration'] = 'Configuració PHP';
$GLOBALS['strCheckError'] = 'error';
$GLOBALS['strCheckErrors'] = 'errors';
$GLOBALS['strCheckWarning'] = 'advertència';
$GLOBALS['strCheckWarnings'] = 'advertències';

/** admin login step * */
$GLOBALS['strLoginProgressMessage'] = 'Iniciant sessió...';

/** database step * */
$GLOBALS['strDbProgressMessageInstall'] = 'S\'està instal·lant la base de dades...';
$GLOBALS['strDbProgressMessageUpgrade'] = 'S\'està actualitzant la base de dades...';
$GLOBALS['strDBInstallSuccess'] = "La base de dades s'ha creat amb èxit";
$GLOBALS['strDBUpgradeSuccess'] = "La base de dades s'ha actualitzat amb èxit";


/** config step * */
$GLOBALS['strConfigureUpgradeTitle'] = "Preferències de configuració";
$GLOBALS['strPreviousInstallTitle'] = "Instal·lació anterior";

/** jobs step * */

$GLOBALS['strPostInstallTaskRunning'] = "Tasca en execució";

/** finish step * */
